/*
 * Biting Blades 2 Hand Management Test
 *
 * With the basic combat engine implemented in mosh, 1sthand will now add
 * a basic user interface allowing for the selection and discarding of cards
 * for a single (human) player in isolation from the combat engine.
 *
 * Feature set:
 *    - Display individual attack or defense cards
 *    - Display all attack and/or defense cards held as an aggregate hand
 *      with appropriate header information and in either long or condensed
 *      format
 *    - Automatically select required cards to the limit of available picks
 *    - Support engine limits on the number of cards that can be drawn or
 *      discarded at a given time
 *    - Allow user to throw any card(s) desired, up to limit of allowed
 *      discards
 */

#include <stdio.h>
#include "bladeui.h"
#include "bladelib.h"
#include "weapons.h"

int main() {
  player_info dancer = {"Dancer", 0, 0, // name, next_impulse, engaged
                        2, 2, 2, 0,     // atk, def, free, null cards
                        0, 0, 0, 0,     // cards held
                        0, 0};          // prev/next player pointers

  randomize();

  // Verify that weapon data structures are OK
  if (!validate_weapon(longsword)) {
    printf("Longsword data is corrupt!\n");
    exit(1);
  }

  if (!validate_weapon(shield)) {
    printf("Shield data is corrupt!\n");
    exit(1);
  }

  draw_cards(&dancer, 0);

  printf("\n\n");

  show_hand(dancer);

  return(0);
}
