/*
 * Basic text-mode interface to Biting Blades 2 engine
 */

#include "bladeui.h"
#include "bladelib.h"
#include "weapons.h"
#include <stdio.h>

enum card_format_enum card_format = card_format_brief;

void show_player_state(player_info player) {
  printf("%s status:  Attack %d, Defense %d, Free %d, Null %d\n",
         player.name, player.atk_avail, player.def_avail,
         player.free_avail, player.null_steps);
  printf("        Next impulse in %d, Engaged %d\n",
         player.next_impulse - get_tick(), player.engaged);
}

void show_weapon(weapon_data weapon) {
  int i;

  printf("%s:  Speed %d, Attack %d, Defense %d/%d\n", weapon.name,
         weapon.speed, weapon.atk_value, weapon.pri_def_value,
         weapon.adj_def_value);
  printf("    Attack Zones: ");
  for (i = head; i <= gut; i++) {
    printf("%s %d  ", location_abbr[i], weapon.attack_chance[i]);
  }
  printf("\n        Specials: ");
  for (i = min_att_spec; i <= max_att_spec; i++) {
    if (weapon.atk_spec_chance[i]) {
      printf("%s %d  ", atk_spec_name[i], weapon.atk_spec_chance[i]);
    }
  }
  printf("\n   Defense Zones: ");
  for (i = head; i <= gut; i++) {
    printf("%s %d ", location_abbr[i], weapon.defense_chance[i]);
  }
  printf("\n        Specials: ");
  for (i = min_def_spec; i <= max_def_spec; i++) {
    if (weapon.def_spec_chance[i]) {
      printf("%s %d ", def_spec_name[i], weapon.def_spec_chance[i]);
    }
  }
  printf("\n");
}

void show_attack_card(attack_card attack) {
  int i;

  // Print strength and target
  printf("%s to %s, strength %d" , attack.weapon->name,
         location_name[attack.location], attack.strength);

  // List specials
  for (i = min_att_spec; i <= max_att_spec; i++) {
    if (attack.special[i]) {
      printf("  %s", atk_spec_name[i]);
    }
  }
  printf("\n");
}

int show_attack_hand(player_info player) {
  attack_card *curr_att = player.head_attack;
  int att_count = 0;

  printf("%s's attack hand:\n", player.name);

  while (curr_att) {
    ++att_count;
    show_attack_card(*curr_att);
    curr_att = curr_att->next_attack;
  }

  return (att_count);
}

void show_defense_card(defense_card defense) {
  int i;

  // Display remaining/total duration of protection
  if (defense.expires) {
    printf("%d/%d  ", defense.expires - get_tick(), defense.duration);
  } else {
    printf("-/%d  ", defense.duration);
  };

  // Print strength by location
  for (i = head; i <= gut; i++) {
    printf("%s: %d  ", location_abbr[i], defense.strength[i]);
  }

  // List specials
  for (i = min_def_spec; i <= max_def_spec; i++) {
    if (defense.special[i]) {
      printf("%s  ", def_spec_name[i]);
    }
  }
  printf("\n");
}

int show_defense_hand(player_info player) {
  defense_card *curr_def = player.head_defense;
  int def_count = 0;

  printf("%s's defense hand:\n", player.name);

  while (curr_def) {
    ++def_count;
    show_defense_card(*curr_def);
    curr_def = curr_def->next_defense;
  }
}

void show_hand(player_info player) {
  show_attack_hand(player);
  printf("\n");
  show_defense_hand(player);
  printf("\n");
}

void draw_cards(player_info *player, int num_cards) {
  int def_draw = player->def_avail - player->def_cards;
  int atk_draw = player->atk_avail - player->atk_cards;
  int free_draw = (player->atk_avail + player->def_avail + player->free_avail)
		   - (player->atk_cards + player->def_cards 
                      + atk_draw + def_draw);

  if (def_draw < 0) def_draw = 0;
  if (atk_draw < 0) atk_draw = 0;

  if (!num_cards) num_cards = atk_draw + def_draw + free_draw;

  while ((num_cards) && (def_draw)) {
    generate_defense_card(player, &shield);
    show_defense_card(*player->head_defense);
    num_cards--;
    def_draw--;
  }

  while ((num_cards) && (atk_draw)) {
    generate_attack_card(player, &longsword);
    show_attack_card(*player->head_attack);
    num_cards--;
    atk_draw--;
  }

  while ((num_cards) && (free_draw)) {
    generate_defense_card(player, &shield);
    show_defense_card(*player->head_defense);
    num_cards--;
    free_draw--;
  }
}

