
/************************************************************************
 * Biting Blades 2, first iteration                                     *
 * This version is just a basic beginning using only syntax introduced  *
 * in chapters 1-12 of the Cow Book (or at least that's the idea; I'm   *
 * sure some later material will slip in).  Most notably, it's in a     *
 * single source file for now.                                          *
 *                                                                      *
 * Feature set:                                                         *
 *    - Basic implementation of the Blades system with only attack/     *
 *      defense/initiative options implemented.  The only supported     *
 *      Special will be Counter.  (Even that would be omitted if the    *
 *      system would remain playable without it.)                       *
 *    - Card generation will make its first appearance here             *
 *    - Multiple weapons will be added in this version also, but the    *
 *      dual-strike ("2") special will not                              *
 *    - Play will be strictly console-based and no AI will be present   *
 *    - Initial weapon will be Longsword with Fist, Foot, and Shield    *
 *      added after multiple-weapon code is in place                    *
 ************************************************************************/

#include <stdio.h>
#include "dslib.h"
#include "bladelib.h"
#include "bladeui.h"
#include "weapons.h"

/*
const weapon_data longsword = {"Longsword",   // name
              10,                             // speed
              3,                              // attack_value
              3,                              // pri_def_value
              1,                              // adj_def_value
              {10, 15, 25, 15, 10, 10, 15},   // att loc
              {15, 20, 20, 15, 10, 10, 10},   // def loc
              {10},                           // atk_spec_chance
              {35}                            // def_spec_chance
            };

const weapon_data shield = {"Shield",         // name
              7,                              // speed
              1,                              // attack_value
              4,                              // pri_def_value
              3,                              // adj_def_value
              {10, 30, 30, 20, 0, 0, 10},     // att loc
              {15, 15, 25, 15, 8, 12, 10},    // def loc
              {0},                            // atk_spec_chance
              {40}                            // def_spec_chance
            };
*/

enum {num_players = 3};
player_info *player[num_players * 2];

int main() {
  int i, j;
  attack_card *atk_card;
  defense_card *def_card;
  player_info *active_player;
  player_info *target_player;
  int both_alive = 1;

  player_info dancer = {"Dancer", 0, 0, // name, next_impulse, engaged
                        0, 0, 6, 0,     // atk, def, free, null cards
                        0, 0, 0, 0,     // cards held
                        0, 0};          // prev/next player pointers

  player_info brutus = {"Brutus", 0, 0, // name, next_impulse, engaged
                        3, 1, 4, 0,     // atk, def, free, null cards
                        0, 0, 0, 0,     // cards held
                        0, 0};          // prev/next player pointers

  player_info bubba  = {"Bubba", 0, 0,  // name, next_impulse, engaged
                        2, 1, 2, 5,     // atk, def, free, null cards
                        0, 0, 0, 0,     // cards held
                        0, 0};          // prev/next player pointers

  randomize();

  // Verify that weapon data structures are OK
  if (!validate_weapon(longsword)) {
    printf("Longsword data is corrupt!\n");
    exit(1);
  }

  if (!validate_weapon(shield)) {
    printf("Shield data is corrupt!\n");
    exit(1);
  }

/*
  player[0] = &dancer;
  player[1] = &brutus;
  player[2] = &bubba;
*/

  add_player(&dancer);
  printf("Registered Dancer on tick %d\n", dancer.next_impulse);
  fflush(stdout);
  
  add_player(&brutus);
  printf("Registered Brutus on tick %d\n", brutus.next_impulse);
  fflush(stdout);

  add_player(&bubba);
  printf("Registered Bubba on tick %d\n", bubba.next_impulse);
  fflush(stdout);

  printf("First combatant is %s\n", next_player()->name);
  fflush(stdout);

  i = list_players(player, 5);
  printf("Got list of %d players:  ", i);
  for (j = 0; j < i; j++) {
    printf("%s  ", player[j]->name);
  }
  printf("\n");

  // Disply all player starting conditions
  for (i = 0; i < num_players; i++) {
    show_player_state(*player[i]);
  }

  // Beat on the characters until one of 'em dies
  while (both_alive) {
    active_player = next_player();
    printf("\n%s's impulse on tick %d - engagement level %d\n",
           active_player->name, get_tick(), 
           active_player->engaged);
    fflush(stdout);
      
    // Cleanup on active_player
    if (active_player->engaged > 0) {
      delay_player(active_player, active_player->engaged);
      active_player->engaged = 0;
      continue;
    }

    while (1) {
      target_player = player[random() % num_players];
      if (target_player->name != active_player->name) {
        break;
      }
    }

    printf("%s attacking %s\n", active_player->name, target_player->name);

    if (target_player->head_defense) {
      show_defense_card(*(target_player->head_defense));
    }
    clear_defense(target_player);

    generate_attack_card(active_player, &longsword);
    atk_card = active_player->head_attack;

    if ((!target_player->head_defense) || 
        (!target_player->head_defense->expires)) {
      generate_defense_card(target_player, &shield);
      def_card = target_player->head_defense;
    } else {
      def_card = 0;
    }
    
    printf("Attack:  ");
    show_attack_card(*atk_card);

    printf("Defense:  ");
    show_defense_card(def_card ? *def_card : *target_player->head_defense);

    both_alive = resolve_attack(active_player, atk_card,
                                target_player, def_card);

    show_player_state(*target_player);

    if (!both_alive) {
      printf("%s has died!\n", target_player->name);
      break;
    }
  }

  return(0);
}
